@@ -31,8 +31,10 @@
 #include <QMessageBox>
 #include <QMouseEvent>
 #include <QTextDocument>
+#ifndef MAEMO
 #include <QPrinter>
 #include <QPrintDialog>
+#endif // MAEMO
 #include "application.h"
 #include "dictbrowser.h"
 #include "speaker.h"
@@ -72,24 +74,38 @@ DictWidget::DictWidget(QWidget *parent, Qt::WindowFlags f)
     m_toolBar = new DictWidgetToolbar(this);
     m_toolBar->setMouseTracking(true);
 
-    QAction *actionBackward = m_toolBar->addAction(QIcon(":/icons/go-previous.png"), tr("Go to &previous translation"),
+    QAction *actionBackward = m_toolBar->addAction(QIcon(":/icons/go-previous.png"), tr("Previous"),
             m_translationView, SLOT(backward()));
     actionBackward->setDisabled(true);
     connect(m_translationView, SIGNAL(backwardAvailable(bool)), actionBackward, SLOT(setEnabled(bool)));
 
-    QAction *actionForward = m_toolBar->addAction(QIcon(":/icons/go-next.png"), tr("Go to &next translation"),
+    QAction *actionForward = m_toolBar->addAction(QIcon(":/icons/go-next.png"), tr("Next"),
             m_translationView, SLOT(forward()));
     actionForward->setDisabled(true);
     connect(m_translationView, SIGNAL(forwardAvailable(bool)), actionForward, SLOT(setEnabled(bool)));
 
-    m_toolBar->addAction(QIcon(":/icons/document-save-as.png"), tr("&Save to file"),
+    QAction *actionSaveToFile = m_toolBar->addAction(QIcon(":/icons/document-save-as.png"), tr("&Save to file"),
             this, SLOT(saveToFile()));
 
-    m_toolBar->addAction(QIcon(":/icons/document-print.png"), tr("Prin&t translation"),
-            this, SLOT(print()));
+    QFont font;
+    font.setPointSize(16);
+    actionBackward->setFont(font);
+    actionForward->setFont(font);
+    actionSaveToFile->setFont(font);
 
-    m_toolBar->addAction(QIcon(":/icons/speaker.png"), tr("Speak &word"),
+    #ifndef MAEMO
+    QAction *actionPrint = m_toolBar->addAction(QIcon(":/icons/document-print.png"), tr("Prin&t translation"),
+            this, SLOT(print()));
+    actionPrint->setFont(font);
+    #endif // MAEMO
+
+    QAction *actionSpeak = m_toolBar->addAction(QIcon(":/icons/speaker.png"), tr("Speak &word"),
             this, SLOT(speak()));
+    actionSpeak->setFont(font);
+    QSize toolBarSize;
+    toolBarSize.setWidth(70);
+    toolBarSize.setHeight(60);
+    m_toolBar->setIconSize(toolBarSize);
 
     QVBoxLayout *layout = new QVBoxLayout(this);
     layout->setMargin(0);
@@ -111,13 +127,20 @@ void DictWidget::on_translationView_sourceChanged(const QUrl &name)
 
 void DictWidget::saveToFile()
 {
+	static QDir dir( QDir::homePath() ); //added by Frank
+	static QString filter(tr("Text files (*.txt)")); //added by Frank
+	
     QFileDialog dialog(this, tr("Save translation"),
-                       QDir::homePath() + "/" + translatedWord());
-    dialog.setFilters(QStringList() << tr("HTML files (*.html, *.htm)") << tr("Text files (*.txt)"));
-    if (dialog.exec() && dialog.selectedFiles().size())
+                       dir.path(), filter); //updated by Frank
+	dialog.selectFile(translatedWord());//added by Frank
+    dialog.setNameFilters(QStringList() << tr("HTML files (*.html *.htm)") << tr("Text files (*.txt)"));//updated by Frank
+    dialog.selectNameFilter(filter); //added by Frank
+
+	if (dialog.exec() && dialog.selectedFiles().size())
     {
         QString fileName = dialog.selectedFiles().first();
-        QString filter = dialog.selectedFilter();
+        /*QString*/ filter = dialog.selectedFilter();//updated by Frank
+		dir = dialog.directory(); //added by Frank
         if (filter == tr("HTML files (*.html, *.htm)") && 
             ! (fileName.endsWith(".html", Qt::CaseInsensitive) || fileName.endsWith(".htm", Qt::CaseInsensitive)))
             fileName += ".html";
@@ -144,6 +167,7 @@ void DictWidget::speak()
     Application::instance()->speaker()->speak(translatedWord());
 }
 
+#ifndef MAEMO
 void DictWidget::print()
 {
     QPrinter printer(QPrinter::HighResolution);
@@ -151,6 +175,7 @@ void DictWidget::print()
     if (dialog.exec() == QDialog::Accepted)
         m_translationView->print(&printer);
 }
+#endif // MAEMO
 
 void DictWidget::setDefaultStyleSheet(const QString &css)
 {
